@@ -1,6 +1,6 @@
 package Git::Hooks;
 # ABSTRACT: Framework for implementing Git (and Gerrit) hooks
-$Git::Hooks::VERSION = '1.6.5';
+$Git::Hooks::VERSION = '1.6.6';
 use 5.010;
 use strict;
 use warnings;
@@ -668,7 +668,7 @@ Git::Hooks - Framework for implementing Git (and Gerrit) hooks
 
 =head1 VERSION
 
-version 1.6.5
+version 1.6.6
 
 =head1 SYNOPSIS
 
@@ -862,7 +862,7 @@ For example:
             my $size = $git->command('cat-file' => '-s', $sha);
             $size <= $LIMIT
                 or $git->error('CheckSize', "File '$name' has $size bytes, more than our limit of $LIMIT"
-                    and $errors++;
+                    and ++$errors;
         }
 
         return $errors == 0;
