@@ -2,7 +2,7 @@
 
 package Git::Hooks::CheckFile;
 # ABSTRACT: Git::Hooks plugin for checking files
-$Git::Hooks::CheckFile::VERSION = '1.6.5';
+$Git::Hooks::CheckFile::VERSION = '1.6.6';
 use 5.010;
 use utf8;
 use strict;
@@ -94,7 +94,7 @@ sub check_affected_refs {
     foreach my $ref ($git->get_affected_refs()) {
         my ($old_commit, $new_commit) = $git->get_affected_ref_range($ref);
         check_new_files($git, $new_commit, $git->filter_files_in_range('AM', $old_commit, $new_commit))
-            or $errors++;
+            or ++$errors;
     }
 
     return $errors == 0;
@@ -136,7 +136,7 @@ Git::Hooks::CheckFile - Git::Hooks plugin for checking files
 
 =head1 VERSION
 
-version 1.6.5
+version 1.6.6
 
 =head1 DESCRIPTION
 
